Topological Constructions
=========================

The key to topological data analysis is 




.. autosummary::
    :toctree: generated/
     
     homology.PersDiag
     multidim.covertree.CoverTree


